@@ -16,6 +16,7 @@
 
 import time
 
+import argh
 import requests
 
 from je.configuration import configuration
@@ -33,7 +34,7 @@ class Jenkins(object):
                                    method='POST',
                                    data=parameters)
         if response.status_code != 201:
-            raise RuntimeError(
+            raise argh.CommandError(
                 'Failed building job: {} [status={}, parameters={}]'
                 .format(job, response.status_code, parameters))
 
@@ -131,6 +132,7 @@ class Jenkins(object):
             next_index = 0
             while True:
                 response = self._raw_query(resource,
+                                           method='POST',
                                            data={'start': next_index})
                 previous_index = next_index
                 next_index = int(response.headers.get('X-Text-Size'))
@@ -155,8 +157,12 @@ class Jenkins(object):
         url = '{}/{}/{}'.format(configuration.jenkins_base_url,
                                 configuration.jenkins_system_tests_base,
                                 resource)
-        return requests.request(method, url,
-                                auth=(configuration.jenkins_username,
-                                      configuration.jenkins_password),
-                                data=data)
+        response = requests.request(method, url,
+                                    auth=(configuration.jenkins_username,
+                                          configuration.jenkins_password),
+                                    data=data)
+        if response.status_code == 404:
+            raise argh.CommandError('Resource not found. (404)'.format(
+                resource))
+        return response
 jenkins = Jenkins()
